| easydb_available_databases | R Documentation |
List databases with configuration details stored in a configuration file.
easydb_available_databases(config_file)
config_file |
path to yaml file containing configuration information about databases (port, host, etc. ) (string) |
database names (character vector)
path_to_config = tempfile() easydb_available_databases(path_to_config)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.