| easydb_init | R Documentation |
Create a file to store your database configurations in.
easydb_init(config_file)
config_file |
path to create a new config file to store database configurations |
invisibly returns path to config file
# Choose config file path
# Do NOT use tempfile in practice.
# Choose a fixed location such as '~/.easydb'
config <- tempfile('.example_config')
# Initialise Configuration File
easydb_init(config)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.